DualFloatVector

Trait DualFloatVector 

pub trait DualFloatVector:
    DualValue
    + FloatVector<Element: DualValue>
    + CastVector<Self>
    + SwizzleVector { }
A real FloatVector usable as the inner storage of a Dual vector.

Requires the value type to support dual arithmetic (DualValue), to be a real float vector whose element is itself a DualValue, and to be castable to itself.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors